/****************************************************************************
** Meta object code from reading C++ file 'audio_watcher.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../audio/audio_watcher.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'audio_watcher.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12AudioWatcherE_t {};
} // unnamed namespace

template <> constexpr inline auto AudioWatcher::qt_create_metaobjectdata<qt_meta_tag_ZN12AudioWatcherE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AudioWatcher",
        "sigVolumeChange",
        "",
        "AudioMode",
        "mode",
        "sigDeviceChange",
        "sigMuteChanged",
        "sigDeviceEnableChanged",
        "enable",
        "sigReduceNoiseChanged",
        "reduceNoiseChanged",
        "onDefaultSourceActivePortChanged",
        "AudioPort",
        "value",
        "onDefaultSinkActivePortChanged",
        "onDefaultSourceChanaged",
        "QDBusObjectPath",
        "onDefaultSinkChanaged",
        "onSourceVolumeChanged",
        "onSinkVolumeChanged",
        "onSourceMuteChanged",
        "onSinkMuteChanged",
        "onDBusAudioPropertyChanged",
        "QDBusMessage",
        "msg",
        "Internal",
        "Micphone"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigVolumeChange'
        QtMocHelpers::SignalData<void(enum AudioMode)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'sigDeviceChange'
        QtMocHelpers::SignalData<void(enum AudioMode)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'sigMuteChanged'
        QtMocHelpers::SignalData<void(enum AudioMode)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'sigDeviceEnableChanged'
        QtMocHelpers::SignalData<void(enum AudioMode, bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 8 },
        }}),
        // Signal 'sigReduceNoiseChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'onDefaultSourceActivePortChanged'
        QtMocHelpers::SlotData<void(AudioPort)>(11, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'onDefaultSinkActivePortChanged'
        QtMocHelpers::SlotData<void(AudioPort)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'onDefaultSourceChanaged'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(15, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 16, 13 },
        }}),
        // Slot 'onDefaultSinkChanaged'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(17, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 16, 13 },
        }}),
        // Slot 'onSourceVolumeChanged'
        QtMocHelpers::SlotData<void(double)>(18, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Double, 13 },
        }}),
        // Slot 'onSinkVolumeChanged'
        QtMocHelpers::SlotData<void(double)>(19, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Double, 13 },
        }}),
        // Slot 'onSourceMuteChanged'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'onSinkMuteChanged'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'onDBusAudioPropertyChanged'
        QtMocHelpers::SlotData<void(QDBusMessage)>(22, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'AudioMode'
        QtMocHelpers::EnumData<enum AudioMode>(3, 3, QMC::EnumFlags{}).add({
            {   25, AudioMode::Internal },
            {   26, AudioMode::Micphone },
        }),
    };
    return QtMocHelpers::metaObjectData<AudioWatcher, qt_meta_tag_ZN12AudioWatcherE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AudioWatcher::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12AudioWatcherE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12AudioWatcherE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12AudioWatcherE_t>.metaTypes,
    nullptr
} };

void AudioWatcher::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AudioWatcher *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigVolumeChange((*reinterpret_cast<std::add_pointer_t<enum AudioMode>>(_a[1]))); break;
        case 1: _t->sigDeviceChange((*reinterpret_cast<std::add_pointer_t<enum AudioMode>>(_a[1]))); break;
        case 2: _t->sigMuteChanged((*reinterpret_cast<std::add_pointer_t<enum AudioMode>>(_a[1]))); break;
        case 3: _t->sigDeviceEnableChanged((*reinterpret_cast<std::add_pointer_t<enum AudioMode>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 4: _t->sigReduceNoiseChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->onDefaultSourceActivePortChanged((*reinterpret_cast<std::add_pointer_t<AudioPort>>(_a[1]))); break;
        case 6: _t->onDefaultSinkActivePortChanged((*reinterpret_cast<std::add_pointer_t<AudioPort>>(_a[1]))); break;
        case 7: _t->onDefaultSourceChanaged((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 8: _t->onDefaultSinkChanaged((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 9: _t->onSourceVolumeChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 10: _t->onSinkVolumeChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 11: _t->onSourceMuteChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->onSinkMuteChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->onDBusAudioPropertyChanged((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AudioWatcher::*)(AudioMode )>(_a, &AudioWatcher::sigVolumeChange, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioWatcher::*)(AudioMode )>(_a, &AudioWatcher::sigDeviceChange, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioWatcher::*)(AudioMode )>(_a, &AudioWatcher::sigMuteChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioWatcher::*)(AudioMode , bool )>(_a, &AudioWatcher::sigDeviceEnableChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioWatcher::*)(bool )>(_a, &AudioWatcher::sigReduceNoiseChanged, 4))
            return;
    }
}

const QMetaObject *AudioWatcher::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AudioWatcher::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12AudioWatcherE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AudioWatcher::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void AudioWatcher::sigVolumeChange(AudioMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AudioWatcher::sigDeviceChange(AudioMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AudioWatcher::sigMuteChanged(AudioMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AudioWatcher::sigDeviceEnableChanged(AudioMode _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void AudioWatcher::sigReduceNoiseChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
