/****************************************************************************
** Meta object code from reading C++ file 'VNoteMainManager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../common/VNoteMainManager.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'VNoteMainManager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16VNoteMainManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto VNoteMainManager::qt_create_metaobjectdata<qt_meta_tag_ZN16VNoteMainManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "VNoteMainManager",
        "finishedFolderLoad",
        "",
        "QList<QVariantMap>",
        "foldersData",
        "updateNotes",
        "notesData",
        "selectIndex",
        "addNoteAtHead",
        "QVariantMap",
        "noteData",
        "addFolderFinished",
        "folderData",
        "noSearchResult",
        "searchFinished",
        "key",
        "moveFinished",
        "QVariantList",
        "index",
        "srcFolderIndex",
        "dstFolderIndex",
        "needUpdateNote",
        "updateRichTextSearch",
        "scrollChange",
        "isTop",
        "updateEditNote",
        "noteId",
        "time",
        "onVNoteFoldersLoaded",
        "onExportFinished",
        "err",
        "onNoteChanged",
        "updateSearch",
        "exitWithSave",
        "vNoteFloderChanged",
        "vNoteChanged",
        "vNoteCreateFolder",
        "vNoteDeleteFolder",
        "createNote",
        "deleteNote",
        "QList<int>",
        "moveNotes",
        "folderIndex",
        "saveAs",
        "path",
        "SaveAsType",
        "type",
        "updateTop",
        "id",
        "top",
        "getTop",
        "updateSort",
        "src",
        "dst",
        "renameFolder",
        "name",
        "renameNote",
        "newName",
        "vNoteSearch",
        "text",
        "updateNoteWithResult",
        "result",
        "loadSearchNotes",
        "loadAudioSource",
        "changeAudioSource",
        "source",
        "insertImages",
        "filePaths",
        "checkNoteVoice",
        "clearSearch",
        "preViewShortcut",
        "QPointF",
        "point",
        "showPrivacy",
        "resumeVoicePlayer",
        "forceExit",
        "needWait",
        "isVoiceToText",
        "Note",
        "Text",
        "Html",
        "Voice"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finishedFolderLoad'
        QtMocHelpers::SignalData<void(const QList<QVariantMap> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'updateNotes'
        QtMocHelpers::SignalData<void(const QList<QVariantMap> &, const int &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 6 }, { QMetaType::Int, 7 },
        }}),
        // Signal 'addNoteAtHead'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'addFolderFinished'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 12 },
        }}),
        // Signal 'noSearchResult'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'searchFinished'
        QtMocHelpers::SignalData<void(const QList<QVariantMap> &, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 6 }, { QMetaType::QString, 15 },
        }}),
        // Signal 'moveFinished'
        QtMocHelpers::SignalData<void(const QVariantList &, const int &, const int &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { QMetaType::Int, 19 }, { QMetaType::Int, 20 },
        }}),
        // Signal 'needUpdateNote'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateRichTextSearch'
        QtMocHelpers::SignalData<void(const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'scrollChange'
        QtMocHelpers::SignalData<void(const bool &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Signal 'updateEditNote'
        QtMocHelpers::SignalData<void(const int &, const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'onVNoteFoldersLoaded'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onExportFinished'
        QtMocHelpers::SlotData<void(int)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 30 },
        }}),
        // Slot 'onNoteChanged'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateSearch'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'exitWithSave'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'vNoteFloderChanged'
        QtMocHelpers::MethodData<void(const int &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Method 'vNoteChanged'
        QtMocHelpers::MethodData<void(const int &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Method 'vNoteCreateFolder'
        QtMocHelpers::MethodData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'vNoteDeleteFolder'
        QtMocHelpers::MethodData<void(const int &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Method 'createNote'
        QtMocHelpers::MethodData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'deleteNote'
        QtMocHelpers::MethodData<void(const QList<int> &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 40, 18 },
        }}),
        // Method 'moveNotes'
        QtMocHelpers::MethodData<void(const QVariantList &, const int &)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { QMetaType::Int, 42 },
        }}),
        // Method 'saveAs'
        QtMocHelpers::MethodData<void(const QVariantList &, const QString &, const SaveAsType)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { QMetaType::QString, 44 }, { 0x80000000 | 45, 46 },
        }}),
        // Method 'saveAs'
        QtMocHelpers::MethodData<void(const QVariantList &, const QString &)>(43, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { QMetaType::QString, 44 },
        }}),
        // Method 'updateTop'
        QtMocHelpers::MethodData<void(const int &, const bool &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 48 }, { QMetaType::Bool, 49 },
        }}),
        // Method 'getTop'
        QtMocHelpers::MethodData<bool()>(50, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'updateSort'
        QtMocHelpers::MethodData<void(const int &, const int &)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 52 }, { QMetaType::Int, 53 },
        }}),
        // Method 'renameFolder'
        QtMocHelpers::MethodData<void(const int &, const QString &)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 }, { QMetaType::QString, 55 },
        }}),
        // Method 'renameNote'
        QtMocHelpers::MethodData<void(const int &, const QString &)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 }, { QMetaType::QString, 57 },
        }}),
        // Method 'vNoteSearch'
        QtMocHelpers::MethodData<void(const QString &)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 59 },
        }}),
        // Method 'updateNoteWithResult'
        QtMocHelpers::MethodData<void(const QString &)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 61 },
        }}),
        // Method 'loadSearchNotes'
        QtMocHelpers::MethodData<int(const QString &)>(62, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 15 },
        }}),
        // Method 'loadAudioSource'
        QtMocHelpers::MethodData<int()>(63, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'changeAudioSource'
        QtMocHelpers::MethodData<void(const int &)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 65 },
        }}),
        // Method 'insertImages'
        QtMocHelpers::MethodData<void(const QStringList &)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 67 },
        }}),
        // Method 'checkNoteVoice'
        QtMocHelpers::MethodData<void(const QVariantList &)>(68, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Method 'clearSearch'
        QtMocHelpers::MethodData<void()>(69, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'preViewShortcut'
        QtMocHelpers::MethodData<void(const QPointF &)>(70, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 71, 72 },
        }}),
        // Method 'showPrivacy'
        QtMocHelpers::MethodData<void()>(73, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'resumeVoicePlayer'
        QtMocHelpers::MethodData<void()>(74, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'forceExit'
        QtMocHelpers::MethodData<void(bool)>(75, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 76 },
        }}),
        // Method 'forceExit'
        QtMocHelpers::MethodData<void()>(75, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'isVoiceToText'
        QtMocHelpers::MethodData<bool()>(77, 2, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'SaveAsType'
        QtMocHelpers::EnumData<enum SaveAsType>(45, 45, QMC::EnumFlags{}).add({
            {   78, SaveAsType::Note },
            {   79, SaveAsType::Text },
            {   80, SaveAsType::Html },
            {   81, SaveAsType::Voice },
        }),
    };
    return QtMocHelpers::metaObjectData<VNoteMainManager, qt_meta_tag_ZN16VNoteMainManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject VNoteMainManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16VNoteMainManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16VNoteMainManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16VNoteMainManagerE_t>.metaTypes,
    nullptr
} };

void VNoteMainManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VNoteMainManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finishedFolderLoad((*reinterpret_cast<std::add_pointer_t<QList<QVariantMap>>>(_a[1]))); break;
        case 1: _t->updateNotes((*reinterpret_cast<std::add_pointer_t<QList<QVariantMap>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->addNoteAtHead((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 3: _t->addFolderFinished((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 4: _t->noSearchResult(); break;
        case 5: _t->searchFinished((*reinterpret_cast<std::add_pointer_t<QList<QVariantMap>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->moveFinished((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 7: _t->needUpdateNote(); break;
        case 8: _t->updateRichTextSearch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->scrollChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->updateEditNote((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 11: _t->onVNoteFoldersLoaded(); break;
        case 12: _t->onExportFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->onNoteChanged(); break;
        case 14: _t->updateSearch(); break;
        case 15: _t->exitWithSave(); break;
        case 16: _t->vNoteFloderChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->vNoteChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->vNoteCreateFolder(); break;
        case 19: _t->vNoteDeleteFolder((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->createNote(); break;
        case 21: _t->deleteNote((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1]))); break;
        case 22: _t->moveNotes((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 23: _t->saveAs((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<enum SaveAsType>>(_a[3]))); break;
        case 24: _t->saveAs((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 25: _t->updateTop((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 26: { bool _r = _t->getTop();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->updateSort((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 28: _t->renameFolder((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 29: _t->renameNote((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 30: _t->vNoteSearch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 31: _t->updateNoteWithResult((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 32: { int _r = _t->loadSearchNotes((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 33: { int _r = _t->loadAudioSource();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 34: _t->changeAudioSource((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 35: _t->insertImages((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 36: _t->checkNoteVoice((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1]))); break;
        case 37: _t->clearSearch(); break;
        case 38: _t->preViewShortcut((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 39: _t->showPrivacy(); break;
        case 40: _t->resumeVoicePlayer(); break;
        case 41: _t->forceExit((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 42: _t->forceExit(); break;
        case 43: { bool _r = _t->isVoiceToText();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (VNoteMainManager::*)(const QList<QVariantMap> & )>(_a, &VNoteMainManager::finishedFolderLoad, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (VNoteMainManager::*)(const QList<QVariantMap> & , const int & )>(_a, &VNoteMainManager::updateNotes, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (VNoteMainManager::*)(const QVariantMap & )>(_a, &VNoteMainManager::addNoteAtHead, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (VNoteMainManager::*)(const QVariantMap & )>(_a, &VNoteMainManager::addFolderFinished, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (VNoteMainManager::*)()>(_a, &VNoteMainManager::noSearchResult, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (VNoteMainManager::*)(const QList<QVariantMap> & , const QString & )>(_a, &VNoteMainManager::searchFinished, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (VNoteMainManager::*)(const QVariantList & , const int & , const int & )>(_a, &VNoteMainManager::moveFinished, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (VNoteMainManager::*)()>(_a, &VNoteMainManager::needUpdateNote, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (VNoteMainManager::*)(const QString & )>(_a, &VNoteMainManager::updateRichTextSearch, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (VNoteMainManager::*)(const bool & )>(_a, &VNoteMainManager::scrollChange, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (VNoteMainManager::*)(const int & , const QString & )>(_a, &VNoteMainManager::updateEditNote, 10))
            return;
    }
}

const QMetaObject *VNoteMainManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VNoteMainManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16VNoteMainManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int VNoteMainManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    return _id;
}

// SIGNAL 0
void VNoteMainManager::finishedFolderLoad(const QList<QVariantMap> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void VNoteMainManager::updateNotes(const QList<QVariantMap> & _t1, const int & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void VNoteMainManager::addNoteAtHead(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void VNoteMainManager::addFolderFinished(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void VNoteMainManager::noSearchResult()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void VNoteMainManager::searchFinished(const QList<QVariantMap> & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void VNoteMainManager::moveFinished(const QVariantList & _t1, const int & _t2, const int & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void VNoteMainManager::needUpdateNote()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void VNoteMainManager::updateRichTextSearch(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void VNoteMainManager::scrollChange(const bool & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void VNoteMainManager::updateEditNote(const int & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}
QT_WARNING_POP
